@@ -40,7 +40,7 @@ void delay_ms(unsigned int ms)
         // accurate and not so much compiler dependent
         // as self made code.
         while(ms){
-                _delay_loop_2(240.0);
+                _delay_ms(0.96);
                 ms--;
         }
 }
@@ -157,7 +157,7 @@ static void store_permanent(void){
 			lcd_puts_P("already stored");
 		}
 	}
-	delay_ms(250);
+	delay_ms(200);
 }
 
 // check the keyboard
@@ -288,11 +288,11 @@ int main(void)
 		// scroll too fast if pressed permanently
 		if (check_buttons()==0){
 			// no buttons pressed
-			delay_ms(250);
+			delay_ms(100);
 			bpress=0;
 			check_i2c_interface();
 			check_buttons();
-			delay_ms(300);
+			delay_ms(150);
 		}else{
 			// button press
 			if (bpress > 11){
@@ -302,9 +302,9 @@ int main(void)
 				delay_ms(40);
 			}else{
 				bpress++;
-				delay_ms(250);
+				delay_ms(100);
 				check_i2c_interface();
-				delay_ms(300);
+				delay_ms(150);
 			}
 		}
 	}
